decode_wirings

Function decode_wirings 

pub fn decode_wirings(wirings_bytes: &[u8]) -> Vec<(u16, u16, u16, u16)>
Given a byte array representing the wirings from the image (2d) to the LH matrix multiplicand (2d), first a flattened u16 array, then serialized as bytes, return the wirings as a Vec of tuples of 4 u16s.